@@ -791,8 +791,11 @@ std::string serializeCard(const T &card, const std::string prod = std::string())
         vcard_4_0::vcards(ostringstream, vcards, map);
         return ostringstream.str();
     } catch  (const xml_schema::exception& e) {
-        CRITICAL("Unknown Exception: failed to write Contact");
+        std::cerr <<  e << std::endl;
+    } catch (...) {
+        CRITICAL("Unhandled exception");
     }
+    CRITICAL("Failed to write vcard!");
     return std::string();
 }
 
@@ -1141,9 +1144,10 @@ boost::shared_ptr<T> deserializeCard(const std::string& s, bool isUrl)
         return card;
     } catch  (const xml_schema::exception& e) {
         std::cerr <<  e << std::endl;
-        CRITICAL("Failed to read card!");
+    } catch (...) {
+        CRITICAL("Unhandled exception");
     }
-
+    CRITICAL("Failed to read vcard!");
     return boost::shared_ptr<T>();
 }
 
