@@ -27,6 +27,7 @@ class BindingsTest : public QObject
     void noteCompletness();
     void eventCompletness();
     void eventDuration();
+    void eventExceptions();
     void todoCompletness();
     void dueDateDateOnly();
     void journalCompletness();
@@ -44,6 +45,9 @@ class BindingsTest : public QObject
     void BenchmarkRoundtripKolab();
     void BenchmarkRoundtrip();
 
+    void preserveLatin1();
+    void preserveUnicode();
+
 };
 
 #endif
\ No newline at end of file
